@@ -14,7 +14,7 @@ class ColorsConfigWidget : public QWidget, private Ui::ColorsConfigWidget
 {
     Q_OBJECT
 public:
-    explicit ColorsConfigWidget(QWidget *parent = 0);
+    explicit ColorsConfigWidget(QWidget *parent = nullptr);
 
 signals:
 
